@@ -15,9 +15,9 @@ int main(int argc, char *argv[])
 
   is_int(termkey_getkey(tk, &key), TERMKEY_RES_KEY, "getkey yields RES_KEY after space");
 
-  is_int(key.type,        TERMKEY_TYPE_UNICODE, "key.type after space");
-  is_int(key.code.number, ' ',                  "key.code.number after space");
-  is_int(key.modifiers,   0,                    "key.modifiers after space");
+  is_int(key.type,           TERMKEY_TYPE_UNICODE, "key.type after space");
+  is_int(key.code.codepoint, ' ',                  "key.code.codepoint after space");
+  is_int(key.modifiers,      0,                    "key.modifiers after space");
 
   termkey_set_flags(tk, TERMKEY_FLAG_SPACESYMBOL);
 
@@ -25,9 +25,9 @@ int main(int argc, char *argv[])
 
   is_int(termkey_getkey(tk, &key), TERMKEY_RES_KEY, "getkey yields RES_KEY after space");
 
-  is_int(key.type,        TERMKEY_TYPE_KEYSYM, "key.type after space with FLAG_SPACESYMBOL");
-  is_int(key.code.number, TERMKEY_SYM_SPACE,   "key.code.sym after space with FLAG_SPACESYMBOL");
-  is_int(key.modifiers,   0,                   "key.modifiers after space with FLAG_SPACESYMBOL");
+  is_int(key.type,      TERMKEY_TYPE_KEYSYM, "key.type after space with FLAG_SPACESYMBOL");
+  is_int(key.code.sym,  TERMKEY_SYM_SPACE,   "key.code.sym after space with FLAG_SPACESYMBOL");
+  is_int(key.modifiers, 0,                   "key.modifiers after space with FLAG_SPACESYMBOL");
 
   termkey_destroy(tk);
 
